@@ -1,4 +1,3 @@
-from collections import namedtuple
 from itertools import chain, islice
 import logging
 # Simplejson prefers str over unicode, looks nicer when printed
@@ -7,18 +6,13 @@ import pika
 import pprint
 import sys
 import time
+import datetime
 
 
 logging.basicConfig()
 pp = pprint.PrettyPrinter(indent=1, width=80, depth=None, stream=None)
 
 
-# Place this here for now... This likely should go with other
-# AMQP stuff, like the handler, but we'll decide later.
-
-Message = namedtuple('Message', 'method properties body')
-
-
 class adict(dict):
     def __init__(self, *args, **kwargs):
         super(adict, self).__init__(*args, **kwargs)
@@ -77,7 +71,7 @@ class messages(object):
                     arguments={'x-message-ttl': 10 * 60 * 1000},
                     exclusive=True,
                     auto_delete=True
-                    )
+                )
                 self.queue = result.method.queue
                 for key in binding_keys:
                     self.channel.queue_bind(self.queue,
@@ -116,7 +110,7 @@ class messages(object):
 
 
 def strtime(t):
-    return time.strftime('%FT%H:%M:%SZ', time.gmtime(int(t)))
+    return datetime.datetime.utcfromtimestamp(t).isoformat() + 'Z'
 
 
 class objects(messages):
